@@ -17,16 +17,29 @@ impl Author {
     ) -> Self {
         let contribution =
             (nbr_of_commits as f32 * 100. / total_nbr_of_commits as f32).round() as usize;
-        Self { name, email, nbr_of_commits, contribution }
+        Self {
+            name,
+            email,
+            nbr_of_commits,
+            contribution,
+        }
     }
 }
 
 impl std::fmt::Display for Author {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
         if let Some(email) = &self.email {
-            write!(f, "{}% {} <{}> {}", self.contribution, self.name, email, self.nbr_of_commits)
+            write!(
+                f,
+                "{}% {} <{}> {}",
+                self.contribution, self.name, email, self.nbr_of_commits
+            )
         } else {
-            write!(f, "{}% {} {}", self.contribution, self.name, self.nbr_of_commits)
+            write!(
+                f,
+                "{}% {} {}",
+                self.contribution, self.name, self.nbr_of_commits
+            )
         }
     }
 }
