@@ -37,8 +37,10 @@ impl Serialize for HeadRefs {
     {
         let mut state = serializer.serialize_struct("HeadRefs", 2)?;
         state.serialize_field("refs", &self.refs)?;
-        state
-            .serialize_field("oid", &self.commit.to_string().chars().take(7).collect::<String>())?;
+        state.serialize_field(
+            "oid",
+            &self.commit.to_string().chars().take(7).collect::<String>(),
+        )?;
         state.end()
     }
 }
