@@ -1,4 +1,4 @@
-use crate::info::language::Language;
+use crate::info::langs::language::Language;
 use colored::Color;
 
 pub mod ascii_art;
@@ -12,8 +12,11 @@ pub fn get_ascii_colors(
     ascii_colors: &[String],
     true_color: bool,
 ) -> Vec<Color> {
-    let language =
-        if let Some(ascii_language) = ascii_language { ascii_language } else { &dominant_language };
+    let language = if let Some(ascii_language) = ascii_language {
+        ascii_language
+    } else {
+        &dominant_language
+    };
 
     let colors = language.get_colors(true_color);
 
